==> slurm_rest_client-0.1.3-py3-none-any.whl: slurm_rest_client/api/slurm/slurm_v0040_get_node.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.slurm_v0040_get_node_flags import SlurmV0040GetNodeFlags
from ...models.slurm_v0040_get_node_response_200 import SlurmV0040GetNodeResponse200
from ...types import UNSET, Response, Unset


def _get_kwargs(
    node_name: str,
    *,
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["update_time"] = update_time

    json_flags: Union[Unset, str] = UNSET
    if not isinstance(flags, Unset):
        json_flags = flags.value

    params["flags"] = json_flags

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/slurm/v0.0.40/node/{node_name}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[SlurmV0040GetNodeResponse200]:
    if response.status_code == 200:
        response_200 = SlurmV0040GetNodeResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[SlurmV0040GetNodeResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Response[SlurmV0040GetNodeResponse200]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SlurmV0040GetNodeResponse200]
    """

    kwargs = _get_kwargs(
        node_name=node_name,
        update_time=update_time,
        flags=flags,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Optional[SlurmV0040GetNodeResponse200]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SlurmV0040GetNodeResponse200
    """

    return sync_detailed(
        node_name=node_name,
        client=client,
        update_time=update_time,
        flags=flags,
    ).parsed


async def asyncio_detailed(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Response[SlurmV0040GetNodeResponse200]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SlurmV0040GetNodeResponse200]
    """

    kwargs = _get_kwargs(
        node_name=node_name,
        update_time=update_time,
        flags=flags,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Optional[SlurmV0040GetNodeResponse200]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SlurmV0040GetNodeResponse200
    """

    return (
        await asyncio_detailed(
            node_name=node_name,
            client=client,
            update_time=update_time,
            flags=flags,
        )
    ).parsed

==> slurm_rest_client-0.1.4-py3-none-any.whl: slurm_rest_client/api/slurm/slurm_v0040_get_node.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.slurm_v0040_get_node_flags import SlurmV0040GetNodeFlags
from ...models.v0040_openapi_nodes_resp import V0040OpenapiNodesResp
from ...types import UNSET, Response, Unset


def _get_kwargs(
    node_name: str,
    *,
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["update_time"] = update_time

    json_flags: Union[Unset, str] = UNSET
    if not isinstance(flags, Unset):
        json_flags = flags.value

    params["flags"] = json_flags

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/slurm/v0.0.40/node/{node_name}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[V0040OpenapiNodesResp]:
    if response.status_code == 200:
        response_200 = V0040OpenapiNodesResp.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[V0040OpenapiNodesResp]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Response[V0040OpenapiNodesResp]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[V0040OpenapiNodesResp]
    """

    kwargs = _get_kwargs(
        node_name=node_name,
        update_time=update_time,
        flags=flags,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Optional[V0040OpenapiNodesResp]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        V0040OpenapiNodesResp
    """

    return sync_detailed(
        node_name=node_name,
        client=client,
        update_time=update_time,
        flags=flags,
    ).parsed


async def asyncio_detailed(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Response[V0040OpenapiNodesResp]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[V0040OpenapiNodesResp]
    """

    kwargs = _get_kwargs(
        node_name=node_name,
        update_time=update_time,
        flags=flags,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    node_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    update_time: Union[Unset, str] = UNSET,
    flags: Union[Unset, SlurmV0040GetNodeFlags] = UNSET,
) -> Optional[V0040OpenapiNodesResp]:
    """get node info

    Args:
        node_name (str):
        update_time (Union[Unset, str]):
        flags (Union[Unset, SlurmV0040GetNodeFlags]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        V0040OpenapiNodesResp
    """

    return (
        await asyncio_detailed(
            node_name=node_name,
            client=client,
            update_time=update_time,
            flags=flags,
        )
    ).parsed
